@@ -2,6 +2,7 @@ from .problem import AbstractKOProblem, AbstractOUProblem
 from mewpy.utils.parsing import GeneEvaluator, build_tree, Boolean
 from collections import OrderedDict
 import logging
+import warnings
 
 logger = logging.getLogger(__name__)
 
@@ -36,13 +37,22 @@ class GKOProblem(AbstractKOProblem):
         target = genes - essential
         if self.non_target:
             target = target - set(self.non_target)
-        self._trg_list = list(target)
+        target =  list(target)
+        try:
+            from mewpy.utils.constants import EAConstants
+            if EAConstants.PROB_TARGET and self.product:
+                from mewpy.utils.graph import probabilistic_gene_targets
+                target = probabilistic_gene_targets(self.model,self.product,target)        
+        except Exception as e:
+            warnings.warn(str(e))
+            
+        self._trg_list = target
 
-    def decode(self, candidate):
+    def solution_to_constraints(self, candidate):
         """
-        Decodes a candidate, an set of genes into a dictionary of constraints.
+        Cpnverts a candidate, an set of genes into a dictionary of constraints.
         """
-        genes = [self.target_list[idx] for idx in candidate]
+        genes = list(candidate.keys())
         active_genes = set(self.simulator.genes) - set(genes)
         active_reactions = self.simulator.evaluate_gprs(active_genes)
         inactive_reactions = set(
@@ -86,7 +96,16 @@ class GOUProblem(AbstractOUProblem):
         target = set(self.simulator.genes)
         if self.non_target:
             target = target - set(self.non_target)
-        self._trg_list = list(target)
+        target =  list(target)
+        try:
+            from mewpy.utils.constants import EAConstants
+            if EAConstants.PROB_TARGET and self.product:
+                from mewpy.utils.graph import probabilistic_gene_targets
+                target = probabilistic_gene_targets(self.model,self.product,target)        
+        except Exception as e:
+            warnings.warn(str(e))
+            
+        self._trg_list = target
 
     def __op(self):
         # set default operators as configurable options
@@ -108,13 +127,12 @@ class GOUProblem(AbstractOUProblem):
                     raise ValueError(f"The operator at index {i} is not callable.")
             self._operators = tuple(ops)
 
-    def decode(self, candidate):
+    def solution_to_constraints(self, candidate):
         """
         Decodes a candidate, a set of (genes,lv) into a dictionary of reaction constraints
         """
         gr_constraints = OrderedDict()
-        genes = {self.target_list[idx]: self.levels[lv_idx]
-                 for idx, lv_idx in candidate}
+        genes = candidate
 
         # operators check
         self.__op()
