@@ -29,7 +29,6 @@ class KOBounder(object):
         self.range = self.upper_bound - self.lower_bound + 1
 
     # make it callable
-
     def __call__(self, candidate, args):
         bounded_candidate = set()
         for val in candidate:
@@ -67,18 +66,24 @@ class AbstractProblem(ABC):
 
     :param model: A Metabolic model.
     :param list fevaluation: A list of callable EvaluationFunctions.
-
+    :param kwargs: Additional parameters dictionary
     """
 
-    def __init__(self, model, fevaluation=None, **kwargs):
+    def __init__(self, model, fevaluation=None,**kwargs):
         self.model = model
         self.fevaluation = fevaluation
         self.number_of_objectives = len(self.fevaluation)
-
+        
         # simulation context : defines the simulations environment
         self.simul_context = None
+        # The target product reaction id may be specified when optimizing for a single product.
+        # Only required for probabilistic modification targeting.
+        self.product = kwargs.get('product', None)
+        # Environmental conditions
         self.environmental_conditions = kwargs.get('envcond', None)
+        # Additional persistent constraints
         self.persistent_constraints = kwargs.get('constraints', None)
+        # Reference reaction fluxes
         self._reference = None
         # solution size
         self.candidate_min_size = kwargs.get(
@@ -116,6 +121,11 @@ class AbstractProblem(ABC):
         """The decoder function for the problem."""
         raise NotImplementedError
 
+    @abstractmethod
+    def solution_to_constraints(self,solution):
+        """Converts a decoded solution to metabolict constraints."""
+        raise NotImplementedError
+
     def get_name(self):
         """The problem name."""
         return self.__class__.__name__
@@ -164,7 +174,7 @@ class AbstractProblem(ABC):
         """
         :returns: The constrainst enconded into an individual.
         """
-        return self.decode(solution.candidate)
+        return solution_to_constaints(self.decode(solution.candidate))
 
     def get_environmental_conditions(self):
         return self.environmental_conditions
@@ -181,11 +191,14 @@ class AbstractProblem(ABC):
         :returns: A list of fitness.
         """
         p = []
+        decoded ={}
         # decoded constraints
         if decode:
-            constraints = self.decode(solution)
+            decoded = self.decode(solution)
+            constraints = self.solution_to_constraints(decoded)
         else:
             constraints = solution
+
         # pre simulation
         simulation_results = OrderedDict()
         try:
@@ -195,7 +208,7 @@ class AbstractProblem(ABC):
                 simulation_results[method] = simulation_result
             # apply the evaluation function(s)
             for f in self.fevaluation:
-                p.append(f(simulation_results, solution,
+                p.append(f(simulation_results, decoded,
                            scalefactor=self.scalefactor))
         except Exception as e:
             for f in self.fevaluation:
@@ -242,7 +255,7 @@ class AbstractProblem(ABC):
         for entry in one_to_remove.keys():
             simul_constraints.remove(entry)
 
-        # test all simoulateous removal
+        # test all simultaneous removal
         fit = self.evaluate_solution(simul_constraints)
         diff = np.abs(np.array(fit)-np.array(fitness))
         is_equal = False
@@ -282,10 +295,22 @@ class AbstractKOProblem(AbstractProblem):
             model, fevaluation=fevaluation, **kwargs)
         self.strategy = Strategy.KO
 
-    @abstractmethod
+
     def decode(self, candidate):
-        """The decode function for the problem."""
-        raise NotImplementedError
+        decoded = {}
+        for idx in candidate:
+            try:
+                decoded[self.target_list[idx]] = 0
+            except IndexError:
+                raise IndexError("Index out of range: {} from {}".format(
+                    idx, len(self.target_list[idx])))
+        return decoded
+
+    def solution_to_constraints(self, decoded_candidate):
+        """
+        Converts a candidate, a dictionary of reactions, into a dictionary of constraints
+        """
+        return decoded_candidate
 
     @property
     def bounder(self):
@@ -297,6 +322,8 @@ class AbstractKOProblem(AbstractProblem):
             self._bounder = KOBounder(0, max)
         return self._bounder
 
+        
+
     def generator(self, random, args):
         """
         Generates a solution, a random int set with length in range min_solution_size to max_solution_size.
@@ -323,6 +350,7 @@ class AbstractKOProblem(AbstractProblem):
             return [self.target_list.index(k) for k in candidate]
 
 
+
 class AbstractOUProblem(AbstractProblem):
     """ Base class for Over/Under expression optimization problems
     """
@@ -344,10 +372,24 @@ class AbstractOUProblem(AbstractProblem):
         self.levels = kwargs.get('levels', EAConstants.LEVELS)
         self._reference = kwargs.get('reference', None)
 
-    @abstractmethod
+
     def decode(self, candidate):
         """The decoder function for the problem. Needs to be implemented by extending classes."""
-        raise NotImplementedError
+        decoded = {}
+        for idx, lv_idx in candidate:
+            try:
+                rxn = self.target_list[idx]
+                lv = self.levels[lv_idx]
+                decoded[rxn]=lv
+            except IndexError:
+                raise IndexError("Index out of range")    
+        return decoded
+
+    def solution_to_constraints(self, decoded_candidate):
+        """
+        Decodes a candidate, a dictionary of reactions, into a dictionary of constraints
+        """
+        return decoded_candidate
 
     @property
     def bounder(self):
@@ -455,3 +497,5 @@ class AbstractOUProblem(AbstractProblem):
         else:
             return [(self.target_list.index(k), self.levels.index(lv))
                     for k, lv in candidate.items()]
+
+   
\ No newline at end of file
